package com.phm.manage.mapper;

import com.phm.manage.domain.ForecastModel;

import java.util.List;

/**
 * 预测模型信息Mapper接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface ForecastModelMapper {
    /**
     * 查询预测模型信息
     *
     * @param id 预测模型信息主键
     * @return 预测模型信息
     */
    public ForecastModel selectForecastModelById(Long id);

    /**
     * 查询预测模型信息列表
     *
     * @param forecastModel 预测模型信息
     * @return 预测模型信息集合
     */
    public List<ForecastModel> selectForecastModelList(ForecastModel forecastModel);

    /**
     * 新增预测模型信息
     *
     * @param forecastModel 预测模型信息
     * @return 结果
     */
    public int insertForecastModel(ForecastModel forecastModel);

    /**
     * 修改预测模型信息
     *
     * @param forecastModel 预测模型信息
     * @return 结果
     */
    public int updateForecastModel(ForecastModel forecastModel);

    /**
     * 删除预测模型信息
     *
     * @param id 预测模型信息主键
     * @return 结果
     */
    public int deleteForecastModelById(Long id);

    /**
     * 批量删除预测模型信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteForecastModelByIds(Long[] ids);
}
